package com.ruoyi.web.modules.farming.mapper;

import java.util.List;
import com.ruoyi.web.modules.farming.domain.BizLivestockKnowledge;

/**
 * 综合牧业知识条目 Mapper
 */
public interface BizLivestockKnowledgeMapper
{
    BizLivestockKnowledge selectBizLivestockKnowledgeById(Long id);

    List<BizLivestockKnowledge> selectBizLivestockKnowledgeList(BizLivestockKnowledge query);

    int insertBizLivestockKnowledge(BizLivestockKnowledge row);

    int updateBizLivestockKnowledge(BizLivestockKnowledge row);

    int logicDeleteBizLivestockKnowledgeByIds(Long[] ids, String updateBy);
}
